AjaxRequestEvent class

Class used by AjaxRequest class. It represents events measuring progress of an AjaxRequest.

Constructors

AjaxRequestEvent({bool? lengthComputable, int? loaded, int? total, AjaxRequestEventType? type})

Properties

hashCode → int
The hash code for this object.
no setterinherited
lengthComputable ↔ bool?
Is a Boolean flag indicating if the total work to be done, and the amount of work already done, by the underlying process is calculable. In other words, it tells if the progress is measurable or not.
getter/setter pair
loaded ↔ int?
Is an integer representing the amount of work already performed by the underlying process. The ratio of work done can be calculated with the property and AjaxRequestEvent.total. When downloading a resource using HTTP, this only represent the part of the content itself, not headers and other overhead.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
total ↔ int?
Is an integer representing the total amount of work that the underlying process is in the progress of performing. When downloading a resource using HTTP, this only represent the content itself, not headers and other overhead.
getter/setter pair
type ↔ AjaxRequestEventType?
Event type.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts instance to a map.
toMap({EnumMethod? enumMethod}) → Map<String, dynamic>
Converts instance to a map.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map<String, dynamic>? map, {EnumMethod? enumMethod}) → AjaxRequestEvent?
Gets a possible AjaxRequestEvent instance from a Map value.