AjaxRequestReadyState class

Class used by AjaxRequest class. It represents the state of an AjaxRequest.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSupported() → bool
Checks if the value is supported by the defaultTargetPlatform.
name() → String
Gets the name of the value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int?
Gets int native value if supported by the current platform, otherwise null.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

values → Set<AjaxRequestReadyState>
Set of all values of AjaxRequestReadyState.
final

Static Methods

asNameMap() → Map<String, AjaxRequestReadyState>
Creates a map from the names of AjaxRequestReadyState values to the values.
byName(String? name) → AjaxRequestReadyState?
Gets a possible AjaxRequestReadyState instance value with name name.
fromNativeValue(int? value) → AjaxRequestReadyState?
Gets a possible AjaxRequestReadyState instance from a native value.
fromValue(int? value) → AjaxRequestReadyState?
Gets a possible AjaxRequestReadyState instance from int value.

Constants

DONE → const AjaxRequestReadyState
The operation is complete.
HEADERS_RECEIVED → const AjaxRequestReadyState
XMLHttpRequest.send() has been called, and AjaxRequest.headers and AjaxRequest.status are available.
LOADING → const AjaxRequestReadyState
Downloading; AjaxRequest.responseText holds partial data.
OPENED → const AjaxRequestReadyState
XMLHttpRequest.open() has been called.
UNSENT → const AjaxRequestReadyState
Client has been created. XMLHttpRequest.open() not called yet.