AndroidVerticalScrollbarPosition class

An Android-specific class used to configure the position of the vertical scroll bar. Use VerticalScrollbarPosition instead.

Annotations
  • @Deprecated('Use VerticalScrollbarPosition instead')

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSupported() → bool
Checks if the value is supported by the defaultTargetPlatform.
name() → String
Gets the name of the value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int?
Gets int native value if supported by the current platform, otherwise null.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

values → Set<AndroidVerticalScrollbarPosition>
Set of all values of AndroidVerticalScrollbarPosition.
final

Static Methods

asNameMap() → Map<String, AndroidVerticalScrollbarPosition>
Creates a map from the names of AndroidVerticalScrollbarPosition values to the values.
byName(String? name) → AndroidVerticalScrollbarPosition?
Gets a possible AndroidVerticalScrollbarPosition instance value with name name.
fromNativeValue(int? value) → AndroidVerticalScrollbarPosition?
Gets a possible AndroidVerticalScrollbarPosition instance from a native value.
fromValue(int? value) → AndroidVerticalScrollbarPosition?
Gets a possible AndroidVerticalScrollbarPosition instance from int value.

Constants

SCROLLBAR_POSITION_DEFAULT → const AndroidVerticalScrollbarPosition
Position the scroll bar at the default position as determined by the system.
SCROLLBAR_POSITION_LEFT → const AndroidVerticalScrollbarPosition
Position the scroll bar along the left edge.
SCROLLBAR_POSITION_RIGHT → const AndroidVerticalScrollbarPosition
Position the scroll bar along the right edge.