AttributedStringTextEffectStyle class

Class that represents the supported proxy types.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSupported() → bool
Checks if the value is supported by the defaultTargetPlatform.
name() → String
Gets the name of the value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → String?
Gets String native value if supported by the current platform, otherwise null.
toString() → String
A string representation of this object.
override
toValue() → String
Gets String value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

values → Set<AttributedStringTextEffectStyle>
Set of all values of AttributedStringTextEffectStyle.
final

Static Methods

asNameMap() → Map<String, AttributedStringTextEffectStyle>
Creates a map from the names of AttributedStringTextEffectStyle values to the values.
byName(String? name) → AttributedStringTextEffectStyle?
Gets a possible AttributedStringTextEffectStyle instance value with name name.
fromNativeValue(String? value) → AttributedStringTextEffectStyle?
Gets a possible AttributedStringTextEffectStyle instance from a native value.
fromValue(String? value) → AttributedStringTextEffectStyle?
Gets a possible AttributedStringTextEffectStyle instance from String value.

Constants

LETTERPRESS_STYLE → const AttributedStringTextEffectStyle
A graphical text effect that gives glyphs the appearance of letterpress printing, which involves pressing the type into the paper.