BrowserProcessExitKind class

The kind of browser process exit that has occurred.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSupported() → bool
Checks if the value is supported by the defaultTargetPlatform.
name() → String
Gets the name of the value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int?
Gets int native value if supported by the current platform, otherwise null.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override
operator |(BrowserProcessExitKind value) → BrowserProcessExitKind

Static Properties

FAILED → BrowserProcessExitKind
Indicates that the browser process ended unexpectedly. A PlatformWebViewCreationParams.onProcessFailed event will also be raised to listening WebViews from the PlatformWebViewEnvironment associated to the failed process.
final
NORMAL → BrowserProcessExitKind
Indicates that the browser process ended normally.
final
values → Set<BrowserProcessExitKind>
Set of all values of BrowserProcessExitKind.
final

Static Methods

asNameMap() → Map<String, BrowserProcessExitKind>
Creates a map from the names of BrowserProcessExitKind values to the values.
byName(String? name) → BrowserProcessExitKind?
Gets a possible BrowserProcessExitKind instance value with name name.
fromNativeValue(int? value) → BrowserProcessExitKind?
Gets a possible BrowserProcessExitKind instance from a native value.
fromValue(int? value) → BrowserProcessExitKind?
Gets a possible BrowserProcessExitKind instance from int value.