BrowserProcessExitedDetail class

An object that contains information for the PlatformWebViewEnvironment.onBrowserProcessExited event.

Constructors

BrowserProcessExitedDetail({required BrowserProcessExitKind kind, int? processId})

Properties

hashCode → int
The hash code for this object.
no setterinherited
kind ↔ BrowserProcessExitKind
The kind of browser process exit that has occurred.
getter/setter pair
processId ↔ int?
The process ID of the browser process that has exited.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts instance to a map.
toMap({EnumMethod? enumMethod}) → Map<String, dynamic>
Converts instance to a map.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map<String, dynamic>? map, {EnumMethod? enumMethod}) → BrowserProcessExitedDetail?
Gets a possible BrowserProcessExitedDetail instance from a Map value.