BrowserProcessInfo class

An object that contains information for a process in the PlatformWebViewEnvironment.

Constructors

BrowserProcessInfo({List<FrameInfo>? frameInfos, required BrowserProcessKind kind, int? processId})

Properties

frameInfos ↔ List<FrameInfo>?
A list of associated FrameInfos which are actively running (showing or hiding UI elements) in the renderer process.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ BrowserProcessKind
The kind of the process.
getter/setter pair
processId ↔ int?
The process id of the process.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts instance to a map.
toMap({EnumMethod? enumMethod}) → Map<String, dynamic>
Converts instance to a map.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map<String, dynamic>? map, {EnumMethod? enumMethod}) → BrowserProcessInfo?
Gets a possible BrowserProcessInfo instance from a Map value.