ChromeSafariBrowserClassOptions class

Class that represents the options that can be used for an ChromeSafariBrowser window. Use ChromeSafariBrowserSettings instead.

Annotations
  • @Deprecated('Use ChromeSafariBrowserSettings instead')

Properties

android ↔ AndroidChromeCustomTabsOptions?
Android-specific options.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ios ↔ IOSSafariOptions?
iOS-specific options.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited