DismissButtonStyle class

Class used to set the custom style for the dismiss button.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSupported() → bool
Checks if the value is supported by the defaultTargetPlatform.
name() → String
Gets the name of the value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int?
Gets int native value if supported by the current platform, otherwise null.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

values → Set<DismissButtonStyle>
Set of all values of DismissButtonStyle.
final

Static Methods

asNameMap() → Map<String, DismissButtonStyle>
Creates a map from the names of DismissButtonStyle values to the values.
byName(String? name) → DismissButtonStyle?
Gets a possible DismissButtonStyle instance value with name name.
fromNativeValue(int? value) → DismissButtonStyle?
Gets a possible DismissButtonStyle instance from a native value.
fromValue(int? value) → DismissButtonStyle?
Gets a possible DismissButtonStyle instance from int value.

Constants

CANCEL → const DismissButtonStyle
Makes the button title the localized string "Cancel".
CLOSE → const DismissButtonStyle
Makes the button title the localized string "Close".
DONE → const DismissButtonStyle
Makes the button title the localized string "Done".