DownloadStartResponse class

Class representing a download response of the WebView used by the event PlatformWebViewCreationParams.onDownloadStartRequest.

Constructors

DownloadStartResponse({DownloadStartResponseAction? action, required bool handled, String? resultFilePath})

Properties

action ↔ DownloadStartResponseAction?
Action to take for the download request.
getter/setter pair
handled ↔ bool
Set this flag to true to hide the default download dialog for this download.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
resultFilePath ↔ String?
The path to the file.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts instance to a map.
toMap({EnumMethod? enumMethod}) → Map<String, dynamic>
Converts instance to a map.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map<String, dynamic>? map, {EnumMethod? enumMethod}) → DownloadStartResponse?
Gets a possible DownloadStartResponse instance from a Map value.