EnvironmentChannelSearchKind class

The channel search kind determines the order that release channels are searched for during PlatformWebViewEnvironment creation.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSupported() → bool
Checks if the value is supported by the defaultTargetPlatform.
name() → String
Gets the name of the value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int?
Gets int native value if supported by the current platform, otherwise null.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

LEAST_STABLE → EnvironmentChannelSearchKind
Search for a release channel from least to most stable: Canary -> Dev -> Beta -> WebView2 Runtime.
final
MOST_STABLE → EnvironmentChannelSearchKind
Search for a release channel from most to least stable: WebView2 Runtime -> Beta -> Dev -> Canary. This is the default behavior.
final
values → Set<EnvironmentChannelSearchKind>
Set of all values of EnvironmentChannelSearchKind.
final

Static Methods

asNameMap() → Map<String, EnvironmentChannelSearchKind>
Creates a map from the names of EnvironmentChannelSearchKind values to the values.
byName(String? name) → EnvironmentChannelSearchKind?
Gets a possible EnvironmentChannelSearchKind instance value with name name.
fromNativeValue(int? value) → EnvironmentChannelSearchKind?
Gets a possible EnvironmentChannelSearchKind instance from a native value.
fromValue(int? value) → EnvironmentChannelSearchKind?
Gets a possible EnvironmentChannelSearchKind instance from int value.