EnvironmentReleaseChannels class

The WebView2 release channels searched for during PlatformWebViewEnvironment creation.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSupported() → bool
Checks if the value is supported by the defaultTargetPlatform.
name() → String
Gets the name of the value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int?
Gets int native value if supported by the current platform, otherwise null.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override
operator |(EnvironmentReleaseChannels value) → EnvironmentReleaseChannels

Static Properties

BETA → EnvironmentReleaseChannels
The Beta release channel that is released every 4 weeks, a week before the stable release.
final
CANARY → EnvironmentReleaseChannels
The Canary release channel that is released daily.
final
DEV → EnvironmentReleaseChannels
The Dev release channel that is released weekly.
final
NONE → EnvironmentReleaseChannels
No release channel. Passing only this value results in HRESULT_FROM_WIN32(ERROR_FILE_NOT_FOUND).
final
STABLE → EnvironmentReleaseChannels
The stable WebView2 Runtime that is released every 4 weeks.
final
values → Set<EnvironmentReleaseChannels>
Set of all values of EnvironmentReleaseChannels.
final

Static Methods

asNameMap() → Map<String, EnvironmentReleaseChannels>
Creates a map from the names of EnvironmentReleaseChannels values to the values.
byName(String? name) → EnvironmentReleaseChannels?
Gets a possible EnvironmentReleaseChannels instance value with name name.
fromNativeValue(int? value) → EnvironmentReleaseChannels?
Gets a possible EnvironmentReleaseChannels instance from a native value.
fromValue(int? value) → EnvironmentReleaseChannels?
Gets a possible EnvironmentReleaseChannels instance from int value.