EnvironmentScrollbarStyle class

The ScrollBar style used during PlatformWebViewEnvironment creation.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSupported() → bool
Checks if the value is supported by the defaultTargetPlatform.
name() → String
Gets the name of the value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int?
Gets int native value if supported by the current platform, otherwise null.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

DEFAULT → EnvironmentScrollbarStyle
Browser default ScrollBar style.
final
FLUENT_OVERLAY → EnvironmentScrollbarStyle
Window style fluent overlay scroll bar. Please see Fluent UI for more details on fluent UI.
final
values → Set<EnvironmentScrollbarStyle>
Set of all values of EnvironmentScrollbarStyle.
final

Static Methods

asNameMap() → Map<String, EnvironmentScrollbarStyle>
Creates a map from the names of EnvironmentScrollbarStyle values to the values.
byName(String? name) → EnvironmentScrollbarStyle?
Gets a possible EnvironmentScrollbarStyle instance value with name name.
fromNativeValue(int? value) → EnvironmentScrollbarStyle?
Gets a possible EnvironmentScrollbarStyle instance from a native value.
fromValue(int? value) → EnvironmentScrollbarStyle?
Gets a possible EnvironmentScrollbarStyle instance from int value.