FindOptions class

Class that represents find options for find-on-page operations.

Constructors

FindOptions({String? findTerm, bool? shouldHighlightAllMatches, bool? shouldMatchCase, bool? shouldMatchWord, bool? suppressDefaultFindDialog})

Properties

findTerm ↔ String?
The text to find.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shouldHighlightAllMatches ↔ bool?
Whether to highlight all matches.
getter/setter pair
shouldMatchCase ↔ bool?
Whether to match case.
getter/setter pair
shouldMatchWord ↔ bool?
Whether to match whole word only.
getter/setter pair
suppressDefaultFindDialog ↔ bool?
Whether to suppress the default find dialog.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts instance to a map.
toMap({EnumMethod? enumMethod}) → Map<String, dynamic>
Converts instance to a map.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map<String, dynamic>? map, {EnumMethod? enumMethod}) → FindOptions?
Gets a possible FindOptions instance from a Map value.