FocusDirection class

Class used to indicate the force dark mode.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSupported() → bool
Checks if the value is supported by the defaultTargetPlatform.
name() → String
Gets the name of the value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int?
Gets int native value if supported by the current platform, otherwise null.
toString() → String
A string representation of this object.
override
toValue() → String
Gets String value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

DOWN → FocusDirection
Move focus down.
final
LEFT → FocusDirection
Move focus to the left.
final
Move focus to the right.
final
UP → FocusDirection
Move focus up.
final
values → Set<FocusDirection>
Set of all values of FocusDirection.
final

Static Methods

asNameMap() → Map<String, FocusDirection>
Creates a map from the names of FocusDirection values to the values.
byName(String? name) → FocusDirection?
Gets a possible FocusDirection instance value with name name.
fromNativeValue(int? value) → FocusDirection?
Gets a possible FocusDirection instance from a native value.
fromValue(String? value) → FocusDirection?
Gets a possible FocusDirection instance from String value.