FrameKind class

Class used to indicate the the frame kind.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSupported() → bool
Checks if the value is supported by the defaultTargetPlatform.
name() → String
Gets the name of the value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int?
Gets int native value if supported by the current platform, otherwise null.
toString() → String
A string representation of this object.
override
toValue() → String
Gets String value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

EMBED → FrameKind
Indicates that the frame is an embed element.
final
IFRAME → FrameKind
Indicates that the frame is an iframe.
final
MAIN_FRAME → FrameKind
Indicates that the frame is a primary main frame(webview).
final
OBJECT → FrameKind
Indicates that the frame is an object element.
final
UNKNOWN → FrameKind
Indicates that the frame is an unknown type frame. We may extend this enum type to identify more frame kinds in the future.
final
values → Set<FrameKind>
Set of all values of FrameKind.
final

Static Methods

asNameMap() → Map<String, FrameKind>
Creates a map from the names of FrameKind values to the values.
byName(String? name) → FrameKind?
Gets a possible FrameKind instance value with name name.
fromNativeValue(int? value) → FrameKind?
Gets a possible FrameKind instance from a native value.
fromValue(String? value) → FrameKind?
Gets a possible FrameKind instance from String value.