HTTPCookieSameSitePolicy class

Class that represents the same site policy of a cookie. Used by the Cookie class.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSupported() → bool
Checks if the value is supported by the defaultTargetPlatform.
name() → String
Gets the name of the value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → String?
Gets String native value if supported by the current platform, otherwise null.
toString() → String
A string representation of this object.
override
toValue() → String
Gets String value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

values → Set<HTTPCookieSameSitePolicy>
Set of all values of HTTPCookieSameSitePolicy.
final

Static Methods

asNameMap() → Map<String, HTTPCookieSameSitePolicy>
Creates a map from the names of HTTPCookieSameSitePolicy values to the values.
byName(String? name) → HTTPCookieSameSitePolicy?
Gets a possible HTTPCookieSameSitePolicy instance value with name name.
fromNativeValue(String? value) → HTTPCookieSameSitePolicy?
Gets a possible HTTPCookieSameSitePolicy instance from a native value.
fromValue(String? value) → HTTPCookieSameSitePolicy?
Gets a possible HTTPCookieSameSitePolicy instance from String value.

Constants

LAX → const HTTPCookieSameSitePolicy
SameSite=Lax;
NONE → const HTTPCookieSameSitePolicy
SameSite=None;
STRICT → const HTTPCookieSameSitePolicy
SameSite=Strict;