IOSNavigationResponseAction class

Class that is used by PlatformWebViewCreationParams.onNavigationResponse event. It represents the policy to pass back to the decision handler. Use NavigationResponseAction instead.

Annotations
  • @Deprecated('Use NavigationResponseAction instead')

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSupported() → bool
Checks if the value is supported by the defaultTargetPlatform.
name() → String
Gets the name of the value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int?
Gets int native value if supported by the current platform, otherwise null.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

values → Set<IOSNavigationResponseAction>
Set of all values of IOSNavigationResponseAction.
final

Static Methods

asNameMap() → Map<String, IOSNavigationResponseAction>
Creates a map from the names of IOSNavigationResponseAction values to the values.
byName(String? name) → IOSNavigationResponseAction?
Gets a possible IOSNavigationResponseAction instance value with name name.
fromNativeValue(int? value) → IOSNavigationResponseAction?
Gets a possible IOSNavigationResponseAction instance from a native value.
fromValue(int? value) → IOSNavigationResponseAction?
Gets a possible IOSNavigationResponseAction instance from int value.

Constants

ALLOW → const IOSNavigationResponseAction
Allow the navigation to continue.
CANCEL → const IOSNavigationResponseAction
Cancel the navigation.