IOSUIModalPresentationStyle class

An iOS-specific class used to specify the modal presentation style when presenting a view controller. Use ModalPresentationStyle instead.

Annotations
  • @Deprecated('Use ModalPresentationStyle instead')

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSupported() → bool
Checks if the value is supported by the defaultTargetPlatform.
name() → String
Gets the name of the value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int?
Gets int native value if supported by the current platform, otherwise null.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

values → Set<IOSUIModalPresentationStyle>
Set of all values of IOSUIModalPresentationStyle.
final

Static Methods

asNameMap() → Map<String, IOSUIModalPresentationStyle>
Creates a map from the names of IOSUIModalPresentationStyle values to the values.
byName(String? name) → IOSUIModalPresentationStyle?
Gets a possible IOSUIModalPresentationStyle instance value with name name.
fromNativeValue(int? value) → IOSUIModalPresentationStyle?
Gets a possible IOSUIModalPresentationStyle instance from a native value.
fromValue(int? value) → IOSUIModalPresentationStyle?
Gets a possible IOSUIModalPresentationStyle instance from int value.

Constants

AUTOMATIC → const IOSUIModalPresentationStyle
The default presentation style chosen by the system.
CURRENT_CONTEXT → const IOSUIModalPresentationStyle
A presentation style where the content is displayed over another view controller’s content.
CUSTOM → const IOSUIModalPresentationStyle
A custom view presentation style that is managed by a custom presentation controller and one or more custom animator objects.
FORM_SHEET → const IOSUIModalPresentationStyle
A presentation style that displays the content centered in the screen.
FULL_SCREEN → const IOSUIModalPresentationStyle
A presentation style in which the presented view covers the screen.
NONE → const IOSUIModalPresentationStyle
A presentation style that indicates no adaptations should be made.
OVER_CURRENT_CONTEXT → const IOSUIModalPresentationStyle
A presentation style where the content is displayed over another view controller’s content.
OVER_FULL_SCREEN → const IOSUIModalPresentationStyle
A view presentation style in which the presented view covers the screen.
PAGE_SHEET → const IOSUIModalPresentationStyle
A presentation style that partially covers the underlying content.
POPOVER → const IOSUIModalPresentationStyle
A presentation style where the content is displayed in a popover view.