IOSUIScrollViewDecelerationRate class

Class that represents a floating-point value that determines the rate of deceleration after the user lifts their finger. Use ScrollViewDecelerationRate instead.

Annotations
  • @Deprecated('Use ScrollViewDecelerationRate instead')

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSupported() → bool
Checks if the value is supported by the defaultTargetPlatform.
name() → String
Gets the name of the value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → String?
Gets String native value if supported by the current platform, otherwise null.
toString() → String
A string representation of this object.
override
toValue() → String
Gets String value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

values → Set<IOSUIScrollViewDecelerationRate>
Set of all values of IOSUIScrollViewDecelerationRate.
final

Static Methods

asNameMap() → Map<String, IOSUIScrollViewDecelerationRate>
Creates a map from the names of IOSUIScrollViewDecelerationRate values to the values.
byName(String? name) → IOSUIScrollViewDecelerationRate?
Gets a possible IOSUIScrollViewDecelerationRate instance value with name name.
fromNativeValue(String? value) → IOSUIScrollViewDecelerationRate?
Gets a possible IOSUIScrollViewDecelerationRate instance from a native value.
fromValue(String? value) → IOSUIScrollViewDecelerationRate?
Gets a possible IOSUIScrollViewDecelerationRate instance from String value.

Constants

FAST → const IOSUIScrollViewDecelerationRate
A fast deceleration rate for a scroll view: 0.99.
NORMAL → const IOSUIScrollViewDecelerationRate
The default deceleration rate for a scroll view: 0.998.