JavaScriptHandlerFunctionData class

A class that represents the data passed to a JavaScriptHandlerFunction added with PlatformInAppWebViewController.addJavaScriptHandler.

Constructors

JavaScriptHandlerFunctionData({List args = const [], required bool isMainFrame, required WebUri origin, required WebUri requestUrl})

Properties

args ↔ List
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isMainFrame ↔ bool
getter/setter pair
origin ↔ WebUri
getter/setter pair
requestUrl ↔ WebUri
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts instance to a map.
toMap({EnumMethod? enumMethod}) → Map<String, dynamic>
Converts instance to a map.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map<String, dynamic>? map, {EnumMethod? enumMethod}) → JavaScriptHandlerFunctionData?
Gets a possible JavaScriptHandlerFunctionData instance from a Map value.