LaunchingExternalUriSchemeResponse class

Class that represents the response used by the PlatformWebViewCreationParams.onLaunchingExternalUriScheme event.

Constructors

LaunchingExternalUriSchemeResponse({required bool cancel})

Properties

cancel ↔ bool
Set to true to cancel the external URI scheme launch.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts instance to a map.
toMap({EnumMethod? enumMethod}) → Map<String, dynamic>
Converts instance to a map.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map<String, dynamic>? map, {EnumMethod? enumMethod}) → LaunchingExternalUriSchemeResponse?
Gets a possible LaunchingExternalUriSchemeResponse instance from a Map value.