MediaPlaybackState class

Class that describes whether an audio or video presentation is playing, paused, or suspended.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSupported() → bool
Checks if the value is supported by the defaultTargetPlatform.
name() → String
Gets the name of the value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int?
Gets int native value if supported by the current platform, otherwise null.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

values → Set<MediaPlaybackState>
Set of all values of MediaPlaybackState.
final

Static Methods

asNameMap() → Map<String, MediaPlaybackState>
Creates a map from the names of MediaPlaybackState values to the values.
byName(String? name) → MediaPlaybackState?
Gets a possible MediaPlaybackState instance value with name name.
fromNativeValue(int? value) → MediaPlaybackState?
Gets a possible MediaPlaybackState instance from a native value.
fromValue(int? value) → MediaPlaybackState?
Gets a possible MediaPlaybackState instance from int value.

Constants

NONE → const MediaPlaybackState
There is no media to play back.
PAUSED → const MediaPlaybackState
The media playback is paused.
PLAYING → const MediaPlaybackState
The media is playing.
SUSPENDED → const MediaPlaybackState
The media is not playing, and cannot be resumed until the user revokes the suspension.