ModalPresentationStyle class

Class used to specify the modal presentation style when presenting a view controller.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSupported() → bool
Checks if the value is supported by the defaultTargetPlatform.
name() → String
Gets the name of the value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int?
Gets int native value if supported by the current platform, otherwise null.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

values → Set<ModalPresentationStyle>
Set of all values of ModalPresentationStyle.
final

Static Methods

asNameMap() → Map<String, ModalPresentationStyle>
Creates a map from the names of ModalPresentationStyle values to the values.
byName(String? name) → ModalPresentationStyle?
Gets a possible ModalPresentationStyle instance value with name name.
fromNativeValue(int? value) → ModalPresentationStyle?
Gets a possible ModalPresentationStyle instance from a native value.
fromValue(int? value) → ModalPresentationStyle?
Gets a possible ModalPresentationStyle instance from int value.

Constants

AUTOMATIC → const ModalPresentationStyle
The default presentation style chosen by the system.
CURRENT_CONTEXT → const ModalPresentationStyle
A presentation style where the content is displayed over another view controller’s content.
CUSTOM → const ModalPresentationStyle
A custom view presentation style that is managed by a custom presentation controller and one or more custom animator objects.
FORM_SHEET → const ModalPresentationStyle
A presentation style that displays the content centered in the screen.
FULL_SCREEN → const ModalPresentationStyle
A presentation style in which the presented view covers the screen.
NONE → const ModalPresentationStyle
A presentation style that indicates no adaptations should be made.
OVER_CURRENT_CONTEXT → const ModalPresentationStyle
A presentation style where the content is displayed over another view controller’s content.
OVER_FULL_SCREEN → const ModalPresentationStyle
A view presentation style in which the presented view covers the screen.
PAGE_SHEET → const ModalPresentationStyle
A presentation style that partially covers the underlying content.
POPOVER → const ModalPresentationStyle
A presentation style where the content is displayed in a popover view.