NavigationActionPolicy class

Class that is used by PlatformWebViewCreationParams.shouldOverrideUrlLoading event. It represents the policy to pass back to the decision handler.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSupported() → bool
Checks if the value is supported by the defaultTargetPlatform.
name() → String
Gets the name of the value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int?
Gets int native value if supported by the current platform, otherwise null.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

values → Set<NavigationActionPolicy>
Set of all values of NavigationActionPolicy.
final

Static Methods

asNameMap() → Map<String, NavigationActionPolicy>
Creates a map from the names of NavigationActionPolicy values to the values.
byName(String? name) → NavigationActionPolicy?
Gets a possible NavigationActionPolicy instance value with name name.
fromNativeValue(int? value) → NavigationActionPolicy?
Gets a possible NavigationActionPolicy instance from a native value.
fromValue(int? value) → NavigationActionPolicy?
Gets a possible NavigationActionPolicy instance from int value.

Constants

ALLOW → const NavigationActionPolicy
Allow the navigation to continue.
CANCEL → const NavigationActionPolicy
Cancel the navigation.
DOWNLOAD → const NavigationActionPolicy
Turn the navigation into a download.