NavigationResponseAction class

Class that is used by PlatformWebViewCreationParams.onNavigationResponse event. It represents the policy to pass back to the decision handler.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSupported() → bool
Checks if the value is supported by the defaultTargetPlatform.
name() → String
Gets the name of the value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int?
Gets int native value if supported by the current platform, otherwise null.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

values → Set<NavigationResponseAction>
Set of all values of NavigationResponseAction.
final

Static Methods

asNameMap() → Map<String, NavigationResponseAction>
Creates a map from the names of NavigationResponseAction values to the values.
byName(String? name) → NavigationResponseAction?
Gets a possible NavigationResponseAction instance value with name name.
fromNativeValue(int? value) → NavigationResponseAction?
Gets a possible NavigationResponseAction instance from a native value.
fromValue(int? value) → NavigationResponseAction?
Gets a possible NavigationResponseAction instance from int value.

Constants

ALLOW → const NavigationResponseAction
Allow the navigation to continue.
CANCEL → const NavigationResponseAction
Cancel the navigation.
DOWNLOAD → const NavigationResponseAction
Turn the navigation into a download.