NotificationReceivedRequest class

Class that represents the request used by the PlatformWebViewCreationParams.onNotificationReceived event.

This class bundles the senderOrigin and the notificationController that can be used to interact with the web notification (report shown, clicked, closed, etc.).

Constructors

NotificationReceivedRequest({PlatformWebNotificationController? notificationController, WebUri? senderOrigin})

Properties

hashCode → int
The hash code for this object.
no setterinherited
notificationController ↔ PlatformWebNotificationController?
The notification controller that provides methods to interact with the notification.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
senderOrigin ↔ WebUri?
The origin of the web content that sends the notification.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts instance to a map.
toMap({EnumMethod? enumMethod}) → Map<String, dynamic>
Converts instance to a map.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited