PdfToolbarItems class

Class used to customize the PDF toolbar items.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSupported() → bool
Checks if the value is supported by the defaultTargetPlatform.
name() → String
Gets the name of the value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int?
Gets int native value if supported by the current platform, otherwise null.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override
operator |(PdfToolbarItems value) → PdfToolbarItems

Static Properties

values → Set<PdfToolbarItems>
Set of all values of PdfToolbarItems.
final

Static Methods

asNameMap() → Map<String, PdfToolbarItems>
Creates a map from the names of PdfToolbarItems values to the values.
byName(String? name) → PdfToolbarItems?
Gets a possible PdfToolbarItems instance value with name name.
fromNativeValue(int? value) → PdfToolbarItems?
Gets a possible PdfToolbarItems instance from a native value.
fromValue(int? value) → PdfToolbarItems?
Gets a possible PdfToolbarItems instance from int value.

Constants

BOOKMARKS → const PdfToolbarItems
The bookmarks button.
FIT_PAGE → const PdfToolbarItems
The fit page button.
FULL_SCREEN → const PdfToolbarItems
The full screen button.
MORE_SETTINGS → const PdfToolbarItems
The more settings button.
NONE → const PdfToolbarItems
No item.
PAGE_LAYOUT → const PdfToolbarItems
The page layout button.
PAGE_SELECTOR → const PdfToolbarItems
The page select button.
PRINT → const PdfToolbarItems
The print button.
ROTATE → const PdfToolbarItems
The rotate button.
SAVE → const PdfToolbarItems
The save button.
SAVE_AS → const PdfToolbarItems
The save as button.
The search button.
ZOOM_IN → const PdfToolbarItems
The zoom in button.
ZOOM_OUT → const PdfToolbarItems
The zoom out button.