PermissionRequestResponseAction class

Class used by PermissionRequestResponse class. Use PermissionResponseAction instead.

Annotations
  • @Deprecated('Use PermissionResponseAction instead')

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSupported() → bool
Checks if the value is supported by the defaultTargetPlatform.
name() → String
Gets the name of the value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int?
Gets int native value if supported by the current platform, otherwise null.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

values → Set<PermissionRequestResponseAction>
Set of all values of PermissionRequestResponseAction.
final

Static Methods

asNameMap() → Map<String, PermissionRequestResponseAction>
Creates a map from the names of PermissionRequestResponseAction values to the values.
byName(String? name) → PermissionRequestResponseAction?
Gets a possible PermissionRequestResponseAction instance value with name name.
fromNativeValue(int? value) → PermissionRequestResponseAction?
Gets a possible PermissionRequestResponseAction instance from a native value.
fromValue(int? value) → PermissionRequestResponseAction?
Gets a possible PermissionRequestResponseAction instance from int value.

Constants

DENY → const PermissionRequestResponseAction
Denies the request.
GRANT → const PermissionRequestResponseAction
Grants origin the permission to access the given resources.