PermissionResponse class

Class that represents the response used by the PlatformWebViewCreationParams.onPermissionRequest event.

Constructors

PermissionResponse({PermissionResponseAction? action, List<PermissionResourceType> resources = const []})

Properties

action ↔ PermissionResponseAction?
Indicate the PermissionResponseAction to take in response of a permission request.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
resources ↔ List<PermissionResourceType>
Resources granted to be accessed by origin.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts instance to a map.
toMap({EnumMethod? enumMethod}) → Map<String, dynamic>
Converts instance to a map.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map<String, dynamic>? map, {EnumMethod? enumMethod}) → PermissionResponse?
Gets a possible PermissionResponse instance from a Map value.