PermissionResponseAction class

Class used by PermissionResponse class.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSupported() → bool
Checks if the value is supported by the defaultTargetPlatform.
name() → String
Gets the name of the value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int?
Gets int native value if supported by the current platform, otherwise null.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

values → Set<PermissionResponseAction>
Set of all values of PermissionResponseAction.
final

Static Methods

asNameMap() → Map<String, PermissionResponseAction>
Creates a map from the names of PermissionResponseAction values to the values.
byName(String? name) → PermissionResponseAction?
Gets a possible PermissionResponseAction instance value with name name.
fromNativeValue(int? value) → PermissionResponseAction?
Gets a possible PermissionResponseAction instance from a native value.
fromValue(int? value) → PermissionResponseAction?
Gets a possible PermissionResponseAction instance from int value.

Constants

DENY → const PermissionResponseAction
Denies the request.
GRANT → const PermissionResponseAction
Grants origin the permission to access the given resources.
PROMPT → const PermissionResponseAction
Prompt the user for permission for the requested resource.