PhysicalKeyStatus class

Contains the information packed into the LPARAM sent to a Win32 key event.

Constructors

PhysicalKeyStatus({required bool isExtendedKey, required bool isKeyReleased, required bool isMenuKeyDown, required int repeatCount, required int scanCode, required bool wasKeyDown})

Properties

hashCode → int
The hash code for this object.
no setterinherited
isExtendedKey ↔ bool
Indicates that the key is an extended key.
getter/setter pair
isKeyReleased ↔ bool
Indicates that the key was released.
getter/setter pair
isMenuKeyDown ↔ bool
Indicates that a menu key is held down (context code).
getter/setter pair
repeatCount ↔ int
Specifies the repeat count for the current message.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scanCode ↔ int
Specifies the scan code.
getter/setter pair
wasKeyDown ↔ bool
Indicates that the key was held down.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts instance to a map.
toMap({EnumMethod? enumMethod}) → Map<String, dynamic>
Converts instance to a map.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map<String, dynamic>? map, {EnumMethod? enumMethod}) → PhysicalKeyStatus?
Gets a possible PhysicalKeyStatus instance from a Map value.