PrewarmingToken class

Class that represents the Prewarming Token returned by PlatformChromeSafariBrowser.prewarmConnections.

Constructors

PrewarmingToken({required String id})

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String
Prewarming Token id.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts instance to a map.
toMap({EnumMethod? enumMethod}) → Map<String, dynamic>
Converts instance to a map.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map<String, dynamic>? map, {EnumMethod? enumMethod}) → PrewarmingToken?
Gets a possible PrewarmingToken instance from a Map value.