PrintJobDialogKind class

Class representing the print dialog kind used by a PlatformPrintJobController.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSupported() → bool
Checks if the value is supported by the defaultTargetPlatform.
name() → String
Gets the name of the value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int?
Gets int native value if supported by the current platform, otherwise null.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

values → Set<PrintJobDialogKind>
Set of all values of PrintJobDialogKind.
final

Static Methods

asNameMap() → Map<String, PrintJobDialogKind>
Creates a map from the names of PrintJobDialogKind values to the values.
byName(String? name) → PrintJobDialogKind?
Gets a possible PrintJobDialogKind instance value with name name.
fromNativeValue(int? value) → PrintJobDialogKind?
Gets a possible PrintJobDialogKind instance from a native value.
fromValue(int? value) → PrintJobDialogKind?
Gets a possible PrintJobDialogKind instance from int value.

Constants

BROWSER → const PrintJobDialogKind
Use the browser print dialog UI.
SYSTEM → const PrintJobDialogKind
Use the system print dialog UI.