PrintJobDisposition class

Class representing the constants that specify values for the print job disposition of a PlatformPrintJobController.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSupported() → bool
Checks if the value is supported by the defaultTargetPlatform.
name() → String
Gets the name of the value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → String?
Gets String native value if supported by the current platform, otherwise null.
toString() → String
A string representation of this object.
override
toValue() → String
Gets String value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

CANCEL → PrintJobDisposition
Cancel print job.
final
PREVIEW → PrintJobDisposition
Send to Preview application.
final
SAVE → PrintJobDisposition
Save to a file.
final
SPOOL → PrintJobDisposition
Normal print job.
final
values → Set<PrintJobDisposition>
Set of all values of PrintJobDisposition.
final

Static Methods

asNameMap() → Map<String, PrintJobDisposition>
Creates a map from the names of PrintJobDisposition values to the values.
byName(String? name) → PrintJobDisposition?
Gets a possible PrintJobDisposition instance value with name name.
fromNativeValue(String? value) → PrintJobDisposition?
Gets a possible PrintJobDisposition instance from a native value.
fromValue(String? value) → PrintJobDisposition?
Gets a possible PrintJobDisposition instance from String value.