PrintJobOrientation class

Class representing the orientation of a PlatformPrintJobController.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSupported() → bool
Checks if the value is supported by the defaultTargetPlatform.
name() → String
Gets the name of the value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int?
Gets int native value if supported by the current platform, otherwise null.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

LANDSCAPE → PrintJobOrientation
Pages are printed in landscape orientation.
final
PORTRAIT → PrintJobOrientation
Pages are printed in portrait orientation.
final
values → Set<PrintJobOrientation>
Set of all values of PrintJobOrientation.
final

Static Methods

asNameMap() → Map<String, PrintJobOrientation>
Creates a map from the names of PrintJobOrientation values to the values.
byName(String? name) → PrintJobOrientation?
Gets a possible PrintJobOrientation instance value with name name.
fromNativeValue(int? value) → PrintJobOrientation?
Gets a possible PrintJobOrientation instance from a native value.
fromValue(int? value) → PrintJobOrientation?
Gets a possible PrintJobOrientation instance from int value.