PrintJobPaginationMode class

Class representing the constants that specify the different ways in which an image is divided into pages of a PlatformPrintJobController.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSupported() → bool
Checks if the value is supported by the defaultTargetPlatform.
name() → String
Gets the name of the value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int?
Gets int native value if supported by the current platform, otherwise null.
toString() → String
A string representation of this object.
override
toValue() → String
Gets String value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

AUTOMATIC → PrintJobPaginationMode
Officially Supported Platforms/Implementations:
final
CLIP → PrintJobPaginationMode
Officially Supported Platforms/Implementations:
final
FIT → PrintJobPaginationMode
Officially Supported Platforms/Implementations:
final
values → Set<PrintJobPaginationMode>
Set of all values of PrintJobPaginationMode.
final

Static Methods

asNameMap() → Map<String, PrintJobPaginationMode>
Creates a map from the names of PrintJobPaginationMode values to the values.
byName(String? name) → PrintJobPaginationMode?
Gets a possible PrintJobPaginationMode instance value with name name.
fromNativeValue(int? value) → PrintJobPaginationMode?
Gets a possible PrintJobPaginationMode instance from a native value.
fromValue(String? value) → PrintJobPaginationMode?
Gets a possible PrintJobPaginationMode instance from String value.