PrintJobRenderingQuality class

Class representing the rendering quality of a PlatformPrintJobController.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSupported() → bool
Checks if the value is supported by the defaultTargetPlatform.
name() → String
Gets the name of the value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int?
Gets int native value if supported by the current platform, otherwise null.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

BEST → PrintJobRenderingQuality
Renders the printing at the best possible quality, regardless of speed.
final
RESPONSIVE → PrintJobRenderingQuality
Sacrifices the least possible amount of rendering quality for speed to maintain a responsive user interface. This option should be used only after establishing that best quality rendering does indeed make the user interface unresponsive.
final
values → Set<PrintJobRenderingQuality>
Set of all values of PrintJobRenderingQuality.
final

Static Methods

asNameMap() → Map<String, PrintJobRenderingQuality>
Creates a map from the names of PrintJobRenderingQuality values to the values.
byName(String? name) → PrintJobRenderingQuality?
Gets a possible PrintJobRenderingQuality instance value with name name.
fromNativeValue(int? value) → PrintJobRenderingQuality?
Gets a possible PrintJobRenderingQuality instance from a native value.
fromValue(int? value) → PrintJobRenderingQuality?
Gets a possible PrintJobRenderingQuality instance from int value.