ProcessFailedReason class

Class used to indicate the kind of process failure that has occurred.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSupported() → bool
Checks if the value is supported by the defaultTargetPlatform.
name() → String
Gets the name of the value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int?
Gets int native value if supported by the current platform, otherwise null.
toString() → String
A string representation of this object.
override
toValue() → String
Gets String value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

CRASHED → ProcessFailedReason
The process crashed.
final
LAUNCH_FAILED → ProcessFailedReason
The process failed to launch.
final
OUT_OF_MEMORY → ProcessFailedReason
The process terminated due to running out of memory.
final
TERMINATED → ProcessFailedReason
The process was terminated. For example, from Task Manager.
final
UNEXPECTED → ProcessFailedReason
An unexpected process failure occurred.
final
UNRESPONSIVE → ProcessFailedReason
The process became unresponsive. This only applies to the main frame's render process.
final
values → Set<ProcessFailedReason>
Set of all values of ProcessFailedReason.
final

Static Methods

asNameMap() → Map<String, ProcessFailedReason>
Creates a map from the names of ProcessFailedReason values to the values.
byName(String? name) → ProcessFailedReason?
Gets a possible ProcessFailedReason instance value with name name.
fromNativeValue(int? value) → ProcessFailedReason?
Gets a possible ProcessFailedReason instance from a native value.
fromValue(String? value) → ProcessFailedReason?
Gets a possible ProcessFailedReason instance from String value.