ProcessGlobalConfigSettings class

Class that represents the settings used to configure the PlatformProcessGlobalConfig.

Officially Supported Platforms/Implementations:

Constructors

ProcessGlobalConfigSettings({String? dataDirectorySuffix, ProcessGlobalConfigDirectoryBasePaths? directoryBasePaths})
Officially Supported Platforms/Implementations:

Properties

dataDirectorySuffix ↔ String?
The directory name suffix to be used for the current process. Must not contain a path separator and should not be empty.
getter/setter pair
directoryBasePaths ↔ ProcessGlobalConfigDirectoryBasePaths?
Set the base directories that WebView will use for the current process. If this method is not used, WebView uses the default base paths defined by the Android framework.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copy() → ProcessGlobalConfigSettings
Returns a copy of ProcessGlobalConfigSettings.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts instance to a map.
toMap({EnumMethod? enumMethod}) → Map<String, dynamic>
Converts instance to a map.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map<String, dynamic>? map, {EnumMethod? enumMethod}) → ProcessGlobalConfigSettings?
Gets a possible ProcessGlobalConfigSettings instance from a Map value.
isClassSupported({TargetPlatform? platform}) → bool
Check if the current class is supported by the defaultTargetPlatform or a specific platform.
isPropertySupported(ProcessGlobalConfigSettingsProperty property, {TargetPlatform? platform}) → bool
Check if the current class is supported by the defaultTargetPlatform or a specific platform.