ProxySettingsProperty enum

List of ProxySettings's properties that can be used to check i they are supported or not by the current platform.

Inheritance
Available extensions

Values

bypassRules → const ProxySettingsProperty

Can be used to check if the ProxySettings.bypassRules property is supported at runtime.

Officially Supported Platforms/Implementations:

Use the ProxySettings.isPropertySupported method to check if this property is supported at runtime.

bypassSimpleHostnames → const ProxySettingsProperty

Can be used to check if the ProxySettings.bypassSimpleHostnames property is supported at runtime.

Officially Supported Platforms/Implementations:

  • Android WebView

Use the ProxySettings.isPropertySupported method to check if this property is supported at runtime.

directs → const ProxySettingsProperty

Can be used to check if the ProxySettings.directs property is supported at runtime.

Officially Supported Platforms/Implementations:

  • Android WebView

Use the ProxySettings.isPropertySupported method to check if this property is supported at runtime.

proxyRules → const ProxySettingsProperty

Can be used to check if the ProxySettings.proxyRules property is supported at runtime.

Officially Supported Platforms/Implementations:

  • Android WebView
  • iOS WKWebView
  • macOS WKWebView
  • Linux WPE WebKit

Use the ProxySettings.isPropertySupported method to check if this property is supported at runtime.

removeImplicitRules → const ProxySettingsProperty

Can be used to check if the ProxySettings.removeImplicitRules property is supported at runtime.

Officially Supported Platforms/Implementations:

  • Android WebView

Use the ProxySettings.isPropertySupported method to check if this property is supported at runtime.

reverseBypassEnabled → const ProxySettingsProperty

Can be used to check if the ProxySettings.reverseBypassEnabled property is supported at runtime.

Officially Supported Platforms/Implementations:

  • Android WebView

Use the ProxySettings.isPropertySupported method to check if this property is supported at runtime.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<ProxySettingsProperty>
A constant List of the values in this enum, in order of their declaration.