PullToRefreshSettingsProperty enum

List of PullToRefreshSettings's properties that can be used to check i they are supported or not by the current platform.

Inheritance
Available extensions

Values

attributedTitle → const PullToRefreshSettingsProperty

Can be used to check if the PullToRefreshSettings.attributedTitle property is supported at runtime.

Officially Supported Platforms/Implementations:

  • iOS WKWebView

Use the PullToRefreshSettings.isPropertySupported method to check if this property is supported at runtime.

backgroundColor → const PullToRefreshSettingsProperty

Can be used to check if the PullToRefreshSettings.backgroundColor property is supported at runtime.

Officially Supported Platforms/Implementations:

  • Android WebView
  • iOS WKWebView

Use the PullToRefreshSettings.isPropertySupported method to check if this property is supported at runtime.

color → const PullToRefreshSettingsProperty

Can be used to check if the PullToRefreshSettings.color property is supported at runtime.

Officially Supported Platforms/Implementations:

  • Android WebView
  • iOS WKWebView

Use the PullToRefreshSettings.isPropertySupported method to check if this property is supported at runtime.

distanceToTriggerSync → const PullToRefreshSettingsProperty

Can be used to check if the PullToRefreshSettings.distanceToTriggerSync property is supported at runtime.

Officially Supported Platforms/Implementations:

  • Android WebView

Use the PullToRefreshSettings.isPropertySupported method to check if this property is supported at runtime.

enabled → const PullToRefreshSettingsProperty

Can be used to check if the PullToRefreshSettings.enabled property is supported at runtime.

Officially Supported Platforms/Implementations:

  • Android WebView
  • iOS WKWebView

Use the PullToRefreshSettings.isPropertySupported method to check if this property is supported at runtime.

size → const PullToRefreshSettingsProperty

Can be used to check if the PullToRefreshSettings.size property is supported at runtime.

Officially Supported Platforms/Implementations:

  • Android WebView

Use the PullToRefreshSettings.isPropertySupported method to check if this property is supported at runtime.

slingshotDistance → const PullToRefreshSettingsProperty

Can be used to check if the PullToRefreshSettings.slingshotDistance property is supported at runtime.

Officially Supported Platforms/Implementations:

  • Android WebView

Use the PullToRefreshSettings.isPropertySupported method to check if this property is supported at runtime.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<PullToRefreshSettingsProperty>
A constant List of the values in this enum, in order of their declaration.