SafeBrowsingThreat class

Class that represents the reason the resource was caught by Safe Browsing.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSupported() → bool
Checks if the value is supported by the defaultTargetPlatform.
name() → String
Gets the name of the value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int?
Gets int native value if supported by the current platform, otherwise null.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

values → Set<SafeBrowsingThreat>
Set of all values of SafeBrowsingThreat.
final

Static Methods

asNameMap() → Map<String, SafeBrowsingThreat>
Creates a map from the names of SafeBrowsingThreat values to the values.
byName(String? name) → SafeBrowsingThreat?
Gets a possible SafeBrowsingThreat instance value with name name.
fromNativeValue(int? value) → SafeBrowsingThreat?
Gets a possible SafeBrowsingThreat instance from a native value.
fromValue(int? value) → SafeBrowsingThreat?
Gets a possible SafeBrowsingThreat instance from int value.

Constants

SAFE_BROWSING_THREAT_BILLING → const SafeBrowsingThreat
The resource was blocked because it may trick the user into a billing agreement.
SAFE_BROWSING_THREAT_MALWARE → const SafeBrowsingThreat
The resource was blocked because it contains malware.
SAFE_BROWSING_THREAT_PHISHING → const SafeBrowsingThreat
The resource was blocked because it contains deceptive content.
SAFE_BROWSING_THREAT_UNKNOWN → const SafeBrowsingThreat
The resource was blocked for an unknown reason.
SAFE_BROWSING_THREAT_UNWANTED_SOFTWARE → const SafeBrowsingThreat
The resource was blocked because it contains unwanted software.