SaveAsKind class

Constants that describe the Save As kind.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSupported() → bool
Checks if the value is supported by the defaultTargetPlatform.
name() → String
Gets the name of the value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int?
Gets int native value if supported by the current platform, otherwise null.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

values → Set<SaveAsKind>
Set of all values of SaveAsKind.
final

Static Methods

asNameMap() → Map<String, SaveAsKind>
Creates a map from the names of SaveAsKind values to the values.
byName(String? name) → SaveAsKind?
Gets a possible SaveAsKind instance value with name name.
fromNativeValue(int? value) → SaveAsKind?
Gets a possible SaveAsKind instance from a native value.
fromValue(int? value) → SaveAsKind?
Gets a possible SaveAsKind instance from int value.

Constants

COMPLETE → const SaveAsKind
Save the page with a resources directory.
DEFAULT → const SaveAsKind
Default kind to save non-HTML content.
HTML_ONLY → const SaveAsKind
Save the page as HTML only.
SINGLE_FILE → const SaveAsKind
Save the page as a single file (MHTML).