SaveAsUIResult class

Constants that describe the result of a programmatic Save As call.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSupported() → bool
Checks if the value is supported by the defaultTargetPlatform.
name() → String
Gets the name of the value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int?
Gets int native value if supported by the current platform, otherwise null.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

values → Set<SaveAsUIResult>
Set of all values of SaveAsUIResult.
final

Static Methods

asNameMap() → Map<String, SaveAsUIResult>
Creates a map from the names of SaveAsUIResult values to the values.
byName(String? name) → SaveAsUIResult?
Gets a possible SaveAsUIResult instance value with name name.
fromNativeValue(int? value) → SaveAsUIResult?
Gets a possible SaveAsUIResult instance from a native value.
fromValue(int? value) → SaveAsUIResult?
Gets a possible SaveAsUIResult instance from int value.

Constants

CANCELLED → const SaveAsUIResult
The user cancelled the Save As operation.
FILE_ALREADY_EXISTS → const SaveAsUIResult
The destination file path already exists.
INVALID_PATH → const SaveAsUIResult
The destination file path is invalid.
KIND_NOT_SUPPORTED → const SaveAsUIResult
The selected Save As kind is not supported.
SUCCESS → const SaveAsUIResult
The Save As operation completed successfully.