ScreenCaptureStartingResponse class

Class that represents the response used by the PlatformWebViewCreationParams.onScreenCaptureStarting event.

Constructors

ScreenCaptureStartingResponse({bool? cancel, bool? handled})

Properties

cancel ↔ bool?
Whether to cancel the screen capture.
getter/setter pair
handled ↔ bool?
Whether the event has been handled.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts instance to a map.
toMap({EnumMethod? enumMethod}) → Map<String, dynamic>
Converts instance to a map.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map<String, dynamic>? map, {EnumMethod? enumMethod}) → ScreenCaptureStartingResponse?
Gets a possible ScreenCaptureStartingResponse instance from a Map value.