SearchResultDisplayStyle class

Constants that describe the results summary the find panel UI includes.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSupported() → bool
Checks if the value is supported by the defaultTargetPlatform.
name() → String
Gets the name of the value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int?
Gets int native value if supported by the current platform, otherwise null.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

values → Set<SearchResultDisplayStyle>
Set of all values of SearchResultDisplayStyle.
final

Static Methods

asNameMap() → Map<String, SearchResultDisplayStyle>
Creates a map from the names of SearchResultDisplayStyle values to the values.
byName(String? name) → SearchResultDisplayStyle?
Gets a possible SearchResultDisplayStyle instance value with name name.
fromNativeValue(int? value) → SearchResultDisplayStyle?
Gets a possible SearchResultDisplayStyle instance from a native value.
fromValue(int? value) → SearchResultDisplayStyle?
Gets a possible SearchResultDisplayStyle instance from int value.

Constants

CURRENT_AND_TOTAL → const SearchResultDisplayStyle
The find panel includes the total number of results the session reports and the index of the target result.
NONE → const SearchResultDisplayStyle
The find panel doesn’t include the number of results the session reports.
TOTAL → const SearchResultDisplayStyle
The find panel includes the total number of results the session reports.