ShowFileChooserRequest class

Constructors

ShowFileChooserRequest({required List<String> acceptTypes, String? filenameHint, required bool isCaptureEnabled, required ShowFileChooserRequestMode mode, String? title})

Properties

acceptTypes → List<String>
An array of acceptable MIME types. The returned MIME type could be partial such as audio/*. The array will be empty if no acceptable types are specified.
final
filenameHint → String?
The file name of a default selection if specified, or null.
final
hashCode → int
The hash code for this object.
no setterinherited
isCaptureEnabled → bool
Preference for a live media captured value (e. g. Camera, Microphone). True indicates capture is enabled, false disabled. Use acceptTypes to determine suitable capture devices.
final
mode → ShowFileChooserRequestMode
The file chooser mode.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String?
The title to use for this file selector. If null a default title should be used.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts instance to a map.
toMap({EnumMethod? enumMethod}) → Map<String, dynamic>
Converts instance to a map.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map<String, dynamic>? map, {EnumMethod? enumMethod}) → ShowFileChooserRequest?
Gets a possible ShowFileChooserRequest instance from a Map value.