ShowFileChooserRequestMode class

It represents file chooser mode of a ShowFileChooserRequest.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSupported() → bool
Checks if the value is supported by the defaultTargetPlatform.
name() → String
Gets the name of the value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int?
Gets int native value if supported by the current platform, otherwise null.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

OPEN → ShowFileChooserRequestMode
Open single file. Requires that the file exists before allowing the user to pick it.
final
OPEN_FOLDER → ShowFileChooserRequestMode
Like Open but allows a folder to be selected. The implementation should enumerate all files selected by this operation. This feature is not supported at the moment.
final
OPEN_MULTIPLE → ShowFileChooserRequestMode
Like Open but allows multiple files to be selected.
final
SAVE → ShowFileChooserRequestMode
Allows picking a nonexistent file and saving it.
final
values → Set<ShowFileChooserRequestMode>
Set of all values of ShowFileChooserRequestMode.
final

Static Methods

asNameMap() → Map<String, ShowFileChooserRequestMode>
Creates a map from the names of ShowFileChooserRequestMode values to the values.
byName(String? name) → ShowFileChooserRequestMode?
Gets a possible ShowFileChooserRequestMode instance value with name name.
fromNativeValue(int? value) → ShowFileChooserRequestMode?
Gets a possible ShowFileChooserRequestMode instance from a native value.
fromValue(int? value) → ShowFileChooserRequestMode?
Gets a possible ShowFileChooserRequestMode instance from int value.