ShowFileChooserResponse class

Constructors

ShowFileChooserResponse({List<String>? filePaths, required bool handledByClient})

Properties

filePaths → List<String>?
The file paths of the selected files or null to cancel the request. Each file path must be a valid file URI using the "file:" scheme.
final
handledByClient → bool
Whether the file chooser request was handled by the client.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts instance to a map.
toMap({EnumMethod? enumMethod}) → Map<String, dynamic>
Converts instance to a map.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map<String, dynamic>? map, {EnumMethod? enumMethod}) → ShowFileChooserResponse?
Gets a possible ShowFileChooserResponse instance from a Map value.