TextDirectionKind class

Constants that describe the text direction.

This corresponds to COREWEBVIEW2_TEXT_DIRECTION_KIND.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSupported() → bool
Checks if the value is supported by the defaultTargetPlatform.
name() → String
Gets the name of the value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int?
Gets int native value if supported by the current platform, otherwise null.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

values → Set<TextDirectionKind>
Set of all values of TextDirectionKind.
final

Static Methods

asNameMap() → Map<String, TextDirectionKind>
Creates a map from the names of TextDirectionKind values to the values.
byName(String? name) → TextDirectionKind?
Gets a possible TextDirectionKind instance value with name name.
fromNativeValue(int? value) → TextDirectionKind?
Gets a possible TextDirectionKind instance from a native value.
fromValue(int? value) → TextDirectionKind?
Gets a possible TextDirectionKind instance from int value.

Constants

DEFAULT → const TextDirectionKind
Default text direction.
LEFT_TO_RIGHT → const TextDirectionKind
Left-to-right text direction.
RIGHT_TO_LEFT → const TextDirectionKind
Right-to-left text direction.