UserPreferredContentMode class

Class that represents the content mode to prefer when loading and rendering a webpage.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSupported() → bool
Checks if the value is supported by the defaultTargetPlatform.
name() → String
Gets the name of the value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int?
Gets int native value if supported by the current platform, otherwise null.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

values → Set<UserPreferredContentMode>
Set of all values of UserPreferredContentMode.
final

Static Methods

asNameMap() → Map<String, UserPreferredContentMode>
Creates a map from the names of UserPreferredContentMode values to the values.
byName(String? name) → UserPreferredContentMode?
Gets a possible UserPreferredContentMode instance value with name name.
fromNativeValue(int? value) → UserPreferredContentMode?
Gets a possible UserPreferredContentMode instance from a native value.
fromValue(int? value) → UserPreferredContentMode?
Gets a possible UserPreferredContentMode instance from int value.

Constants

DESKTOP → const UserPreferredContentMode
Represents content targeting desktop browsers.
MOBILE → const UserPreferredContentMode
Represents content targeting mobile browsers.
The recommended content mode for the current platform.