WebResourceRequestSourceKind class

Constants that describe the source kinds for web resource requests.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSupported() → bool
Checks if the value is supported by the defaultTargetPlatform.
name() → String
Gets the name of the value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int?
Gets int native value if supported by the current platform, otherwise null.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

values → Set<WebResourceRequestSourceKind>
Set of all values of WebResourceRequestSourceKind.
final

Static Methods

asNameMap() → Map<String, WebResourceRequestSourceKind>
Creates a map from the names of WebResourceRequestSourceKind values to the values.
byName(String? name) → WebResourceRequestSourceKind?
Gets a possible WebResourceRequestSourceKind instance value with name name.
fromNativeValue(int? value) → WebResourceRequestSourceKind?
Gets a possible WebResourceRequestSourceKind instance from a native value.
fromValue(int? value) → WebResourceRequestSourceKind?
Gets a possible WebResourceRequestSourceKind instance from int value.

Constants

ALL → const WebResourceRequestSourceKind
All request source kinds.
DOCUMENT → const WebResourceRequestSourceKind
Request originated from a document.
NONE → const WebResourceRequestSourceKind
No request source kind.
SERVICE_WORKER → const WebResourceRequestSourceKind
Request originated from a service worker.
SHARED_WORKER → const WebResourceRequestSourceKind
Request originated from a shared worker.