WebViewInterface class

Class that represents the interfaces that a WebView can support.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSupported() → bool
Checks if the value is supported by the defaultTargetPlatform.
name() → String
Gets the name of the value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → String?
Gets String native value if supported by the current platform, otherwise null.
toString() → String
A string representation of this object.
override
toValue() → String
Gets String value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

values → Set<WebViewInterface>
Set of all values of WebViewInterface.
final

Static Methods

asNameMap() → Map<String, WebViewInterface>
Creates a map from the names of WebViewInterface values to the values.
byName(String? name) → WebViewInterface?
Gets a possible WebViewInterface instance value with name name.
fromNativeValue(String? value) → WebViewInterface?
Gets a possible WebViewInterface instance from a native value.
fromValue(String? value) → WebViewInterface?
Gets a possible WebViewInterface instance from String value.

Constants

ICoreWebView2 → const WebViewInterface
ICoreWebView2_2 → const WebViewInterface
ICoreWebView2_3 → const WebViewInterface
ICoreWebView2_4 → const WebViewInterface
ICoreWebView2_5 → const WebViewInterface
ICoreWebView2_6 → const WebViewInterface
ICoreWebView2_7 → const WebViewInterface
ICoreWebView2_8 → const WebViewInterface
ICoreWebView2_9 → const WebViewInterface
ICoreWebView2_10 → const WebViewInterface
ICoreWebView2_11 → const WebViewInterface
ICoreWebView2_12 → const WebViewInterface
ICoreWebView2_13 → const WebViewInterface
ICoreWebView2_14 → const WebViewInterface
ICoreWebView2_15 → const WebViewInterface
ICoreWebView2_16 → const WebViewInterface
ICoreWebView2_17 → const WebViewInterface
ICoreWebView2_18 → const WebViewInterface
ICoreWebView2_19 → const WebViewInterface
ICoreWebView2_20 → const WebViewInterface
ICoreWebView2_21 → const WebViewInterface
ICoreWebView2_22 → const WebViewInterface
ICoreWebView2_23 → const WebViewInterface
ICoreWebView2_24 → const WebViewInterface
ICoreWebView2_25 → const WebViewInterface
ICoreWebView2_26 → const WebViewInterface
ICoreWebView2_27 → const WebViewInterface
ICoreWebView2_28 → const WebViewInterface
ICoreWebView2CompositionController → const WebViewInterface
ICoreWebView2CompositionController2 → const WebViewInterface
ICoreWebView2CompositionController3 → const WebViewInterface
ICoreWebView2CompositionController4 → const WebViewInterface
ICoreWebView2Controller → const WebViewInterface
ICoreWebView2Controller2 → const WebViewInterface
ICoreWebView2Controller3 → const WebViewInterface
ICoreWebView2Controller4 → const WebViewInterface
ICoreWebView2Environment → const WebViewInterface
ICoreWebView2Environment2 → const WebViewInterface
ICoreWebView2Environment3 → const WebViewInterface
ICoreWebView2Environment4 → const WebViewInterface
ICoreWebView2Environment5 → const WebViewInterface
ICoreWebView2Environment6 → const WebViewInterface
ICoreWebView2Environment7 → const WebViewInterface
ICoreWebView2Environment8 → const WebViewInterface
ICoreWebView2Environment9 → const WebViewInterface
ICoreWebView2Environment10 → const WebViewInterface
ICoreWebView2Environment11 → const WebViewInterface
ICoreWebView2Environment12 → const WebViewInterface
ICoreWebView2Environment13 → const WebViewInterface
ICoreWebView2Environment14 → const WebViewInterface
ICoreWebView2Environment15 → const WebViewInterface
ICoreWebView2Settings → const WebViewInterface
ICoreWebView2Settings2 → const WebViewInterface
ICoreWebView2Settings3 → const WebViewInterface
ICoreWebView2Settings4 → const WebViewInterface
ICoreWebView2Settings5 → const WebViewInterface
ICoreWebView2Settings6 → const WebViewInterface
ICoreWebView2Settings7 → const WebViewInterface
ICoreWebView2Settings8 → const WebViewInterface
ICoreWebView2Settings9 → const WebViewInterface