X509Extension class

Implementers

Constructors

X509Extension({required ASN1Object? block})

Properties

alternativeNameAsStrings → List<String>
no setter
block ↔ ASN1Object?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isCritical → bool
no setter
name → String?
no setter
oid → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → dynamic
no setter
valueAsBlock → ASN1Object?
no setter
valueAsStrings → List<String>
no setter

Methods

generalName({required ASN1Object item}) → String?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited